==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property temporalFilterSettings Temporal filter settings. See Temporal Filter Settings
 */
public data class ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs(
    public val temporalFilterSettings:
    Output<ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsTemporalFilterSettingsArgs>? =
        null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs> {
    override fun toJava():
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs.builder()
            .temporalFilterSettings(
                temporalFilterSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgsBuilder
internal constructor() {
    private var temporalFilterSettings:
        Output<ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsTemporalFilterSettingsArgs>? =
        null

    /**
     * @param value Temporal filter settings. See Temporal Filter Settings
     */
    @JvmName("pwqrmpebkufntpki")
    public suspend
    fun temporalFilterSettings(`value`: Output<ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsTemporalFilterSettingsArgs>) {
        this.temporalFilterSettings = value
    }

    /**
     * @param value Temporal filter settings. See Temporal Filter Settings
     */
    @JvmName("twooeiotpcihdaed")
    public suspend
    fun temporalFilterSettings(`value`: ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsTemporalFilterSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.temporalFilterSettings = mapped
    }

    /**
     * @param argument Temporal filter settings. See Temporal Filter Settings
     */
    @JvmName("hxnglhuejasplupu")
    public suspend
    fun temporalFilterSettings(argument: suspend ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsTemporalFilterSettingsArgsBuilder.() -> Unit) {
        val toBeMapped =
            ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsTemporalFilterSettingsArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.temporalFilterSettings = mapped
    }

    internal fun build():
        ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs =
        ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs(
            temporalFilterSettings = temporalFilterSettings,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property temporalFilterSettings
 */
public data class ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs(
    public val temporalFilterSettings: Output<ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsTemporalFilterSettingsArgs>? =
        null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs> {
    override fun toJava(): com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs.builder()
            .temporalFilterSettings(
                temporalFilterSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgsBuilder
internal constructor() {
    private var temporalFilterSettings:
        Output<ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsTemporalFilterSettingsArgs>? =
        null

    /**
     * @param value
     */
    @JvmName("tdwxxukkupjsyfmx")
    public suspend fun temporalFilterSettings(`value`: Output<ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsTemporalFilterSettingsArgs>) {
        this.temporalFilterSettings = value
    }

    /**
     * @param value
     */
    @JvmName("cvdsclpiejvkpcrw")
    public suspend fun temporalFilterSettings(`value`: ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsTemporalFilterSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.temporalFilterSettings = mapped
    }

    /**
     * @param argument
     */
    @JvmName("egajlkwxhiohabop")
    public suspend fun temporalFilterSettings(argument: suspend ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsTemporalFilterSettingsArgsBuilder.() -> Unit) {
        val toBeMapped =
            ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsTemporalFilterSettingsArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.temporalFilterSettings = mapped
    }

    internal fun build(): ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs =
        ChannelEncoderSettingsVideoDescriptionCodecSettingsH264SettingsFilterSettingsArgs(
            temporalFilterSettings = temporalFilterSettings,
        )
}
